@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\layout_builder\FunctionalJavascript;
 
 use Drupal\block_content\Entity\BlockContentType;
@@ -26,7 +28,7 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'block_content',
     'layout_builder',
     'block',
@@ -44,7 +46,7 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalPlaceBlock('local_tasks_block');
@@ -97,7 +99,11 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
    * Gets the latest block entity id.
    */
   protected function getLatestBlockEntityId() {
-    $block_ids = \Drupal::entityQuery('block_content')->sort('id', 'DESC')->range(0, 1)->execute();
+    $block_ids = \Drupal::entityQuery('block_content')
+      ->accessCheck(FALSE)
+      ->sort('id', 'DESC')
+      ->range(0, 1)
+      ->execute();
     $block_id = array_pop($block_ids);
     $this->assertNotEmpty($this->blockStorage->load($block_id));
     return $block_id;
@@ -106,18 +112,23 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
   /**
    * Removes an entity block from the layout but does not save the layout.
    */
-  protected function removeInlineBlockFromLayout() {
+  protected function removeInlineBlockFromLayout($selector = NULL) {
+    $selector = $selector ?? static::INLINE_BLOCK_LOCATOR;
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
-    $block_text = $page->find('css', static::INLINE_BLOCK_LOCATOR)->getText();
+    $block_text = $page->find('css', $selector)->getText();
     $this->assertNotEmpty($block_text);
     $assert_session->pageTextContains($block_text);
-    $this->clickContextualLink(static::INLINE_BLOCK_LOCATOR, 'Remove block');
+    $this->clickContextualLink($selector, 'Remove block');
     $assert_session->waitForElement('css', "#drupal-off-canvas input[value='Remove']");
     $assert_session->assertWaitOnAjaxRequest();
+
+    // Output the new HTML.
+    $this->htmlOutput($page->getHtml());
+
     $page->find('css', '#drupal-off-canvas')->pressButton('Remove');
     $assert_session->assertNoElementAfterWait('css', '#drupal-off-canvas');
-    $assert_session->assertNoElementAfterWait('css', static::INLINE_BLOCK_LOCATOR);
+    $assert_session->assertNoElementAfterWait('css', $selector);
     $assert_session->assertWaitOnAjaxRequest();
     $assert_session->pageTextNotContains($block_text);
   }
@@ -133,17 +144,17 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
   protected function addInlineBlockToLayout($title, $body) {
     $assert_session = $this->assertSession();
     $page = $this->getSession()->getPage();
-    $page->clickLink('Add Block');
+    $page->clickLink('Add block');
     $assert_session->assertWaitOnAjaxRequest();
-    $this->assertNotEmpty($assert_session->waitForLink('Create custom block'));
-    $this->clickLink('Create custom block');
+    $this->assertNotEmpty($assert_session->waitForLink('Create content block'));
+    $this->clickLink('Create content block');
     $assert_session->assertWaitOnAjaxRequest();
     $textarea = $assert_session->waitForElement('css', '[name="settings[block_form][body][0][value]"]');
     $this->assertNotEmpty($textarea);
     $assert_session->fieldValueEquals('Title', '');
     $page->findField('Title')->setValue($title);
     $textarea->setValue($body);
-    $page->pressButton('Add Block');
+    $page->pressButton('Add block');
     $this->assertDialogClosedAndTextVisible($body, static::INLINE_BLOCK_LOCATOR);
   }
 
@@ -172,23 +183,6 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
     $this->assertDialogClosedAndTextVisible($new_body);
   }
 
-  /**
-   * Waits for an element to be removed from the page.
-   *
-   * @param string $selector
-   *   CSS selector.
-   * @param int $timeout
-   *   (optional) Timeout in milliseconds, defaults to 10000.
-   *
-   * @deprecated in Drupal 8.8.x, will be removed before Drupal 9.0.0. Use
-   *   Drupal\FunctionalJavascriptTests\JSWebAssert::assertNoElementAfterWait()
-   */
-  protected function waitForNoElement($selector, $timeout = 10000) {
-    @trigger_error('::waitForNoElement is deprecated in Drupal 8.8.0 and will be removed before Drupal 9.0.0. Use \Drupal\FunctionalJavascriptTests\JSWebAssert::assertNoElementAfterWait() instead.', E_USER_DEPRECATED);
-    $condition = "(typeof jQuery !== 'undefined' && jQuery('$selector').length === 0)";
-    $this->assertJsCondition($condition, $timeout);
-  }
-
   /**
    * Asserts that the dialog closes and the new text appears on the main canvas.
    *
@@ -200,7 +194,6 @@ abstract class InlineBlockTestBase extends WebDriverTestBase {
   protected function assertDialogClosedAndTextVisible($text, $css_locator = NULL) {
     $assert_session = $this->assertSession();
     $assert_session->assertNoElementAfterWait('css', '#drupal-off-canvas');
-    $assert_session->assertWaitOnAjaxRequest();
     $assert_session->elementNotExists('css', '#drupal-off-canvas');
     if ($css_locator) {
       $this->assertNotEmpty($assert_session->waitForElementVisible('css', ".dialog-off-canvas-main-canvas $css_locator:contains('$text')"));
